@@ -44,7 +44,6 @@
 #include <QGpgME/Protocol>
 #include <QGpgME/KeyListJob>
 
-#include <QToolTip>
 #include <QDateTime>
 #include <QDialogButtonBox>
 #include <QMenu>
@@ -239,7 +238,7 @@ void CertificateDetailsWidget::Private::changePassphrase()
 {
     auto cmd = new Kleo::Commands::ChangePassphraseCommand(key);
     QObject::connect(cmd, &Kleo::Commands::ChangePassphraseCommand::finished,
-                     q, [this, cmd]() {
+                     q, [this]() {
                          ui.changePassphraseBtn->setEnabled(true);
                      });
     ui.changePassphraseBtn->setEnabled(false);
@@ -250,7 +249,7 @@ void CertificateDetailsWidget::Private::genRevokeCert()
 {
     auto cmd = new Kleo::Commands::GenRevokeCommand(key);
     QObject::connect(cmd, &Kleo::Commands::GenRevokeCommand::finished,
-                     q, [this, cmd]() {
+                     q, [this]() {
                          ui.genRevokeBtn->setEnabled(true);
                      });
     ui.genRevokeBtn->setEnabled(false);
@@ -261,7 +260,7 @@ void CertificateDetailsWidget::Private::certifyClicked()
 {
     auto cmd = new Kleo::Commands::CertifyCertificateCommand(key);
     QObject::connect(cmd, &Kleo::Commands::CertifyCertificateCommand::finished,
-                     q, [this, cmd]() {
+                     q, [this]() {
                          ui.certifyBtn->setEnabled(true);
                      });
     ui.certifyBtn->setEnabled(false);
@@ -286,8 +285,10 @@ void CertificateDetailsWidget::Private::addUserID()
 {
     auto cmd = new Kleo::Commands::AddUserIDCommand(key);
     QObject::connect(cmd, &Kleo::Commands::AddUserIDCommand::finished,
-                     q, [this, cmd]() {
+                     q, [this]() {
                          ui.addUserIDBtn->setEnabled(true);
+                         key.update();
+                         q->setKey(key);
                      });
     ui.addUserIDBtn->setEnabled(false);
     cmd->start();
@@ -378,7 +379,7 @@ QString CertificateDetailsWidget::Private::tofuTooltipString(const GpgME::UserID
                          hdr);
     };
     const auto dateTime = [](long ts) {
-        return ts == 0 ? i18n("never") : QDateTime::fromTime_t(ts).toString(Qt::SystemLocaleShortDate);
+        return ts == 0 ? i18n("never") : QDateTime::fromSecsSinceEpoch(ts).toString(Qt::SystemLocaleShortDate);
     };
     appendHeader(i18n("Signing"));
     appendRow(i18n("First message"), dateTime(tofu.signFirst()));
